import datetime
import random

import cnum_converter

import fast_cnum_converter


# 711566042, "LOVEU2"
def generate_string_cnum() -> str:
    return "".join([random.choice("ABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789") for _ in range(6)])  # noqa: S311


def main() -> None:
    amount = 1000000
    cnum_array = [generate_string_cnum() for _ in range(amount)]
    t1 = datetime.datetime.now()  # noqa: DTZ005
    for cnum in cnum_array:
        fast_cnum_converter.convert_cnum_to_numeric(cnum)

    print(f"Rust took: {datetime.datetime.now()-t1}s for {amount} generations.")  # noqa: DTZ005, T201

    t1 = datetime.datetime.now()  # noqa: DTZ005
    for cnum in cnum_array:
        cnum_converter.convert_cnum_to_numeric(cnum)

    print(f"Python took: {datetime.datetime.now()-t1}s for {amount} generations.")  # noqa: DTZ005, T201


if __name__ == "__main__":
    main()



import pytest

import fast_cnum_converter
from fast_cnum_converter import exceptions
from tests.const import CNUM_MAXIMUM


@pytest.mark.parametrize("input_value", [CNUM_MAXIMUM + 1])
def test_convert_cnum_to_alpha__numeric_overflow(input_value: int) -> None:
    with pytest.raises(exceptions.OverflowNumericCNUMError):
        fast_cnum_converter.convert_cnum_to_alpha(fast_cnum_converter.convert_cnum_to_alpha(input_value))


@pytest.mark.parametrize("input_value", [0, -1, -100_000_001])
def test_alpha_to_alpha__nonpositive_numeric(input_value: int) -> None:
    with pytest.raises(exceptions.NonPositiveNumericCNUMError):
        fast_cnum_converter.convert_cnum_to_numeric(fast_cnum_converter.convert_cnum_to_alpha(input_value))


@pytest.mark.parametrize("input_value", ["1TN4WNUBLJ5", ""])
def test_convert_cnum_to_alpha__invalid_alpha_format(input_value: str) -> None:
    with pytest.raises(exceptions.NotInAlphaNumericCNUMFormatError):
        fast_cnum_converter.convert_cnum_to_alpha(fast_cnum_converter.convert_cnum_to_numeric(input_value))


@pytest.mark.parametrize("input_value", ["ABCKEKESTAN", "STUPID   (not real)", "                  ", ""])
def test_convert_cnum_to_alpha__nonint_strings(input_value: str) -> None:
    with pytest.raises(exceptions.ConvertStrToIntCNUMError):
        fast_cnum_converter.convert_cnum_to_alpha(input_value)


@pytest.mark.parametrize("input_value", ["STUPID", "LOVEU2"])
def test_convert_cnum_to_numeric__banned_symbols(input_value: str) -> None:
    with pytest.raises(exceptions.BannedSymbolsInAlphaNumericCNUMError):
        fast_cnum_converter.convert_cnum_to_numeric(input_value, check_banned_symbols=True)


@pytest.mark.parametrize("input_value", [1143194533, 711566042])
def test_convert_cnum_to_alpha__banned_symbols(input_value: int) -> None:
    with pytest.raises(exceptions.BannedSymbolsInAlphaNumericCNUMError):
        fast_cnum_converter.convert_cnum_to_alpha(input_value, check_banned_symbols=True)



import datetime
import random

import cnum_converter

import fast_cnum_converter


def main() -> None:
    amount = 1000000
    t1 = datetime.datetime.now()  # noqa: DTZ005

    for _ in range(amount):
        fast_cnum_converter.convert_cnum_to_alpha(str(random.randrange(1, 1_576_782_335)))  # noqa: S311

    print(f"Rust took: {datetime.datetime.now()-t1}s for {amount} generations.")  # noqa: DTZ005, T201

    t1 = datetime.datetime.now()  # noqa: DTZ005

    for _ in range(amount):
        cnum_converter.convert_cnum_to_alpha(str(random.randrange(1, 1_576_782_335)))  # noqa: S311

    print(f"Python took: {datetime.datetime.now()-t1}s for {amount} generations.")  # noqa: DTZ005, T201


if __name__ == "__main__":
    main()



import dataclasses

import pytest

import fast_cnum_converter


@dataclasses.dataclass
class CnumPair:
    number: int
    alpha: str


GOOD_PAIRS = [
    CnumPair(223, "000223"),
    CnumPair(204, "000204"),
    CnumPair(201, "000201"),
    CnumPair(1959, "001959"),
    CnumPair(6710, "006710"),
    CnumPair(3772, "003772"),
    CnumPair(70647, "070647"),
    CnumPair(86142, "086142"),
    CnumPair(48706, "048706"),
    CnumPair(800801, "800801"),
    CnumPair(279309, "279309"),
    CnumPair(167211, "167211"),
    CnumPair(3005556, "U05556"),
    CnumPair(2801733, "S01733"),
    CnumPair(2942957, "T42957"),
    CnumPair(23834893, "ABEY31"),
    CnumPair(24321953, "ABPDWH"),
    CnumPair(22119064, "AAE654"),
    CnumPair(808064656, "NABPN4"),
    CnumPair(808061369, "NABN3T"),
    CnumPair(808116722, "NACTTE"),
    CnumPair(1000000, "A00000"),
    CnumPair(999999, "999999"),
    CnumPair(3599999, "Z99999"),
    CnumPair(3600000, "9ZD8QO"),
    CnumPair(1576782335, "ZZZZZZ"),
    CnumPair(1143194533, "STUPID"),
    CnumPair(711566042, "LOVEU2"),
    # вдали маячит какой-то зикож! зикож атаковал караван!
    # милорд, крестьяне волнуются — приближается зикож! зикожем единым сыт не будешь!
    CnumPair(1547483647, "ZIK0ZJ"),
]


@pytest.mark.parametrize("input_value", GOOD_PAIRS)
def test_basic_from_numeric_to_alpha(input_value: CnumPair) -> None:
    assert fast_cnum_converter.convert_cnum_to_alpha(input_value.number) == input_value.alpha


@pytest.mark.parametrize("input_value", GOOD_PAIRS)
def test_basic_from_alpha_to_numeric(input_value: CnumPair) -> None:
    assert fast_cnum_converter.convert_cnum_to_numeric(input_value.alpha.upper()) == input_value.number  # type: ignore[comparison-overlap]
    assert fast_cnum_converter.convert_cnum_to_numeric(input_value.alpha.lower()) == input_value.number  # type: ignore[comparison-overlap]


@pytest.mark.parametrize("input_value", GOOD_PAIRS)
def test_cycled_number(input_value: CnumPair) -> None:
    assert (  # type: ignore[comparison-overlap]
        fast_cnum_converter.convert_cnum_to_numeric(fast_cnum_converter.convert_cnum_to_alpha(input_value.number))
    ) == input_value.number


@pytest.mark.parametrize("input_value", GOOD_PAIRS)
def test_cycled_alpha(input_value: CnumPair) -> None:
    assert (
        fast_cnum_converter.convert_cnum_to_alpha(
            fast_cnum_converter.convert_cnum_to_numeric(input_value.alpha.lower()),
        )
    ) == input_value.alpha
    assert (
        fast_cnum_converter.convert_cnum_to_alpha(fast_cnum_converter.convert_cnum_to_numeric(input_value.alpha))
    ) == input_value.alpha


@pytest.mark.parametrize("input_value", GOOD_PAIRS)
def test_alpha_to_alpha(input_value: CnumPair) -> None:
    assert fast_cnum_converter.convert_cnum_to_alpha(input_value.alpha) == input_value.alpha


@pytest.mark.parametrize("input_value", GOOD_PAIRS)
def test_numeric_to_numeric(input_value: CnumPair) -> None:
    assert fast_cnum_converter.convert_cnum_to_numeric(input_value.number) == input_value.number  # type: ignore[comparison-overlap]



class CnumConverterError(Exception):
    """Base class for cnum converter exceptions."""

class ConvertStrToIntCNUMError(CnumConverterError):
    """Raises when cannot convert str to int."""

class NonPositiveNumericCNUMError(CnumConverterError):
    """Raises if negative cnum value was passed in."""

class OverflowNumericCNUMError(CnumConverterError):
    """Raises if too large cnum value was passed in."""

class NotInAlphaNumericCNUMFormatError(CnumConverterError):
    """Raises if non-alphanumeric cnum value was passed in."""

class BannedSymbolsInAlphaNumericCNUMError(CnumConverterError):
    """Raises when cnum contais banned symbols."""



from ._internal.exceptions import (
    BannedSymbolsInAlphaNumericCNUMError,
    CnumConverterError,
    ConvertStrToIntCNUMError,
    NonPositiveNumericCNUMError,
    NotInAlphaNumericCNUMFormatError,
    OverflowNumericCNUMError,
)


__all__ = [
    "CnumConverterError",
    "ConvertStrToIntCNUMError",
    "OverflowNumericCNUMError",
    "NotInAlphaNumericCNUMFormatError",
    "NonPositiveNumericCNUMError",
    "BannedSymbolsInAlphaNumericCNUMError",
]



def convert_cnum_to_alpha(source_maybe_cnum: int | str, check_banned_symbols: bool = False) -> str: ...
def convert_cnum_to_numeric(source_maybe_cnum: int | str, check_banned_symbols: bool = False) -> int: ...
